<?php
/**
 * Clase CapitalInicialBL
 *
 * @package    
 * @subpackage 
 * @author     CapitalInicialBL
 * @version    SVN: $Id: CapitalInicialBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class CapitalInicialBL{
    
  /**
  * 
  *
  * @param $o_CapitalInicialBean, objeto de tipo CapitalInicial 
  * @return Boolean
  */
  public function busquedaCapitalInicial(CapitalInicialBean $o_CapitalInicialBean){
    
    $o_CapitalInicialDP = new CapitalInicialDP($o_CapitalInicialBean);
    if($o_CapitalInicialBean->getIdCapitalInicial()){
      return $o_CapitalInicialDP->selectByPk();
    }else{
      return $o_CapitalInicialDP->select();
    }
    
  }
  
  public function busquedaCapitalInicialResulset(CapitalInicialBean $o_CapitalInicialBean){
    
    $o_CapitalInicialDP = new CapitalInicialDP($o_CapitalInicialBean);
    return $o_CapitalInicialDP->selectResultset();
        
  }
  
  public function insertarCapitalInicial(CapitalInicialBean $o_CapitalInicialBean){
    
    $o_CapitalInicialCT = new CapitalInicialCT();
    return $o_CapitalInicialCT->guardar($o_CapitalInicialBean);
    
  }
  public function modificarCapitalInicial(CapitalInicialBean $o_CapitalInicialBean){
      $o_CapitalInicialCT = new CapitalInicialCT();
      return $o_CapitalInicialCT->modificar($o_CapitalInicialBean);
  }
  /**
	* Función que retorna un objeto CapitalInicial o una lista de Objetos de CapitalInicial,
	* dependiendo del parametro que se le envia si este contiene o no el Id de CapitalInicial
	*
	* @param $o_CapitalInicialBean, es un objeto de tipo CapitalInicial
	* @return Object
	*/
	public function modificarEstadoCapitalInicial(CapitalInicialBean $o_CapitalInicialBean){
	  
	}
  
  public function eliminarCapitalInicial(CapitalInicialBean $o_CapitalInicialBean){
    $o_CapitalInicialCT = new CapitalInicialCT();
    return $o_CapitalInicialCT->eliminar($o_CapitalInicialBean);
    
  }
  
  public function getCountResult(CapitalInicialBean $o_CapitalInicialBean){
    $o_CapitalInicialCT = new CapitalInicialCT();
    return $o_CapitalInicialCT->totalRegistros($o_CapitalInicialBean);
  }
   
  public function getTotalMonto(CapitalInicialBean $o_CapitalInicialBean){
    $o_CapitalInicialCT = new CapitalInicialCT();
    return $o_CapitalInicialCT->totalMonto($o_CapitalInicialBean);
  }
  
}

