<?php

class CapitalInicialSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertCapitalInicial(){
    
    $o_CapitalInicialBL = new CapitalInicialBL();
    return $o_CapitalInicialBL->insertarCapitalInicial($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
   
  public function eliminarCapitalInicial(){
    
    $o_CapitalInicialBL = new CapitalInicialBL();
    return $o_CapitalInicialBL->eliminarCapitalInicial($this->getObjParamBean());
    
  }
  
  public function actualizarCapitalInicial(){
    
    $o_CapitalInicialBL = new CapitalInicialBL();
    return $o_CapitalInicialBL->modificarCapitalInicial($this->getObjParamBean());
    
  }
  
  public function getCapitalInicial(){
  
    $o_CapitalInicialBL = new CapitalInicialBL();
    return $o_CapitalInicialBL->busquedaCapitalInicial($this->getObjParamBean());
  
  }
   
  public function getColaborador(){
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->busquedaColaborador($this->getObjParamBean());
    
  }
  public function getGrado(){
    $o_GradoBL = new GradoBL();
    return $o_GradoBL->busquedaGrado(new GradoBean());
    
  }
  /*public function getColaborador(){
    
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->getbusquedaColaborador($this->getObjParamBean());
  }*/
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }

}